IssueCommand

Enum IssueCommand 

pub enum IssueCommand {
    List {
        owner_repo: Option<String>,
        state: String,
        labels: Vec<String>,
        assignee: Option<String>,
        author: Option<String>,
        mention: Option<String>,
        milestone: Option<String>,
        limit: u32,
        web: bool,
        json: Option<Vec<String>>,
        hostname: Option<String>,
    },
    View {
        number: u64,
        repo: Option<String>,
        web: bool,
        comments: bool,
        json: Option<Vec<String>>,
        hostname: Option<String>,
    },
    Close {
        number: u64,
        repo: Option<String>,
        comment: Option<String>,
        reason: Option<String>,
        hostname: Option<String>,
    },
    Reopen {
        number: u64,
        repo: Option<String>,
        comment: Option<String>,
        hostname: Option<String>,
    },
    Comment {
        number: u64,
        repo: Option<String>,
        body: Option<String>,
        body_file: Option<String>,
        web: bool,
        hostname: Option<String>,
    },
    Create {
        repo: Option<String>,
        title: Option<String>,
        body: Option<String>,
        labels: Vec<String>,
        assignee: Vec<String>,
        milestone: Option<String>,
        project: Option<u32>,
        web: bool,
        hostname: Option<String>,
    },
    Edit {
        number: u64,
        repo: Option<String>,
        title: Option<String>,
        body: Option<String>,
        add_label: Vec<String>,
        remove_label: Vec<String>,
        add_assignee: Vec<String>,
        remove_assignee: Vec<String>,
        milestone: Option<String>,
        hostname: Option<String>,
    },
    Transfer {
        number: u64,
        destination: String,
        repo: Option<String>,
        hostname: Option<String>,
    },
}
Subcommands for gor issue.

Variants



List

List issues in a repository.

Fields

owner_repo: Option<String>

Repository to list issues for (OWNER/REPO format). Auto-detected from git remote if omitted.

state: String

Filter by state: open, closed, or all (default: open).

labels: Vec<String>

Filter by label (repeatable).

assignee: Option<String>

Filter by assignee login.

author: Option<String>

Filter by issue author login.

mention: Option<String>

Filter by @mention.

milestone: Option<String>

Filter by milestone title or number.

limit: u32

Maximum number of issues to show (default: 30).

web: bool

Open the issue list in the default browser.

json: Option<Vec<String>>

Output as JSON. Optionally specify comma-separated field names.

hostname: Option<String>

GitHub hostname for GitHub Enterprise Server (default: github.com).



View

View details of an issue.

Fields

number: u64

Issue number.

repo: Option<String>

Repository to view issue from (OWNER/REPO format). Auto-detected from git remote if omitted.

web: bool

Open the issue in the default browser.

comments: bool

Include the issue’s comment thread.

json: Option<Vec<String>>

Output as JSON. Optionally specify comma-separated field names.

hostname: Option<String>

GitHub hostname for GitHub Enterprise Server (default: github.com).



Close

Close an issue.

Fields

number: u64

Issue number.

repo: Option<String>

Repository (OWNER/REPO format). Auto-detected from git remote if omitted.

comment: Option<String>

Add a closing comment.

reason: Option<String>

Reason for closing: completed or not_planned.

hostname: Option<String>

GitHub hostname for GitHub Enterprise Server (default: github.com).



Reopen

Reopen a closed issue.

Fields

number: u64

Issue number.

repo: Option<String>

Repository (OWNER/REPO format). Auto-detected from git remote if omitted.

comment: Option<String>

Add a comment when reopening.

hostname: Option<String>

GitHub hostname for GitHub Enterprise Server (default: github.com).



Comment

Add a comment to an issue.

Fields

number: u64

Issue number.

repo: Option<String>

Repository (OWNER/REPO format). Auto-detected from git remote if omitted.

body: Option<String>

Comment body (markdown supported).

body_file: Option<String>

Read comment body from file (use @- for stdin).

web: bool

Open the issue in the default browser after commenting.

hostname: Option<String>

GitHub hostname for GitHub Enterprise Server (default: github.com).



Create

Create an issue.

Fields

repo: Option<String>

Repository (OWNER/REPO format). Auto-detected from git remote if omitted.

title: Option<String>

Issue title (required).

body: Option<String>

Issue body (markdown).

labels: Vec<String>

Add labels (repeatable).

assignee: Vec<String>

Assign users by login (repeatable).

milestone: Option<String>

Milestone ID or title.

project: Option<u32>

Add to project board by number.

web: bool

Open the issue in the default browser after creation.

hostname: Option<String>

GitHub hostname for GitHub Enterprise Server (default: github.com).



Edit

Edit an issue.

Fields

number: u64

Issue number.

repo: Option<String>

Repository (OWNER/REPO format). Auto-detected from git remote if omitted.

title: Option<String>

New issue title.

body: Option<String>

New issue body (markdown).

add_label: Vec<String>

Add labels (repeatable).

remove_label: Vec<String>

Remove labels (repeatable).

add_assignee: Vec<String>

Add assignees by login (repeatable).

remove_assignee: Vec<String>

Remove assignees by login (repeatable).

milestone: Option<String>

Milestone ID or title.

hostname: Option<String>

GitHub hostname for GitHub Enterprise Server (default: github.com).



Transfer

Transfer an issue to another repository.

Fields

number: u64

Issue number.

destination: String

Destination repository (OWNER/REPO format).

repo: Option<String>

Source repository (OWNER/REPO format). Auto-detected from git remote if omitted.

hostname: Option<String>

GitHub hostname for GitHub Enterprise Server (default: github.com).