Module alias

Module alias 

Implementation of the gor alias subcommand.

Provides command alias management for listing and setting aliases. Aliases are stored in the config file under the aliases key.

Functions

run
Run the gor alias subcommand.