pub fn run(cmd: AuthCommand) -> Result<()>Expand description
Run the gor auth subcommand.
Errors
Returns an error if authentication fails, the keyring is unavailable, or the network request fails.
pub fn run(cmd: AuthCommand) -> Result<()>Run the gor auth subcommand.
Returns an error if authentication fails, the keyring is unavailable, or the network request fails.