pub fn run(cmd: ConfigCommand, hostname: Option<&str>) -> Result<()>
Run the gor config subcommand.
gor config
Returns an error if the config file cannot be read or written, or if the user provides an invalid key or value.