pub fn config_path() -> Result<PathBuf, ConfigError>Expand description
Returns the path to the config file: ~/.config/gor/config.yml.
Errors
Returns an error if the home directory cannot be determined.
pub fn config_path() -> Result<PathBuf, ConfigError>Returns the path to the config file: ~/.config/gor/config.yml.
Returns an error if the home directory cannot be determined.