load

Function load 

pub fn load() -> Result<GorConfig, ConfigError>
Load the config from disk. Returns a default empty config if the file does not exist.

Errors

Returns an I/O error if the file exists but cannot be read, or if the YAML is malformed.