Module keyring_store

Module keyring_store 

Secure token storage for gor.

Stores OAuth tokens in ~/.config/gor/hosts.yml (mode 0600). Tokens are stored per-host, keyed by hostname.

When the keyring feature is enabled, the OS keyring is used as the primary store with the hosts file as fallback.

Structs

HostEntry
Per-host token storage.
HostsFile
Top-level hosts file structure.

Functions

delete_token
Delete an OAuth token for the given host.
get_token
Retrieve an OAuth token for the given host.
get_user
Retrieve the stored user login for the given host.
set_token
Store an OAuth token for the given host.
set_user
Store the authenticated user’s login name for the given host.