Secure token storage for gor.
Stores OAuth tokens in ~/.config/gor/hosts.yml (mode 0600).
Tokens are stored per-host, keyed by hostname.
When the keyring feature is enabled, the OS keyring is used
as the primary store with the hosts file as fallback.
Structs
Functions
- delete_
token - Delete an OAuth token for the given host.
- get_
token - Retrieve an OAuth token for the given host.
- get_
user - Retrieve the stored user login for the given host.
- set_
token - Store an OAuth token for the given host.
- set_
user - Store the authenticated user’s login name for the given host.